var servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration =
[
    [ "com::sun::star::lang::XInitialization", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration.html#a62f2ca53a1a1cd25174b62b78ef7d524", null ],
    [ "XBackend", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration.html#a720d36e251b410023df08f4a8be76364", null ]
];